# django-cyverse-auth
_Formerly, django-iplant-auth_

A django 'app' that provides easy compatibility with
all current CyVerse Auth schemes.

This app works for both 'resource provider' and 'client'

Protocols currently supported:
- [x] Globus
- [x] WSO2+JWT
- [x] CAS SSO
- [x] CAS OAuth
- [x] LDAP
- [x] Mock (Override auth, always True)
